#[derive(SymbolParsable)]
Derive the Parsable trait by parsing unnamed fields using the FromStr trait.
Parsable
FromStr
Parses the entire name string into each field.
name
Panics if the input is not a tuple struct.